@@ -500,7 +500,7 @@ get_exitstat (list)
   if (arg == 0 || legal_number (arg, &sval) == 0)
     {
       sh_neednumarg (list->word->word ? list->word->word : "`'");
-      return 255;
+      return EX_BADUSAGE;
     }
   no_args (list->next);
 
@@ -628,7 +628,7 @@ get_job_by_name (name, flags)
 	      if (this_shell_builtin)
 	        builtin_error (_("%s: ambiguous job spec"), name);
 	      else
-	        report_error (_("%s: ambiguous job spec"), name);
+	        internal_error (_("%s: ambiguous job spec"), name);
 	      return (DUP_JOB);
 	    }
 	  else
