@@ -42,9 +42,11 @@
 #define Q_DOLBRACE	 0x80
 
 /* Flag values controlling how assignment statements are treated. */
-#define ASS_APPEND	0x01
-#define ASS_MKLOCAL	0x02
-#define ASS_MKASSOC	0x04
+#define ASS_APPEND	0x0001
+#define ASS_MKLOCAL	0x0002
+#define ASS_MKASSOC	0x0004
+#define ASS_MKGLOBAL	0x0008	/* force global assignment */
+#define ASS_NAMEREF	0x0010	/* assigning to nameref variable */
 
 /* Flags for the string extraction functions. */
 #define SX_NOALLOC	0x0001	/* just skip; don't return substring */
@@ -56,6 +58,7 @@
 #define SX_NOLONGJMP	0x0040	/* don't longjmp on fatal error */
 #define SX_ARITHSUB	0x0080	/* extracting $(( ... )) (currently unused) */
 #define SX_POSIXEXP	0x0100	/* extracting new Posix pattern removal expansions in extract_dollar_brace_string */
+#define SX_WORD		0x0200	/* extracting word in ${param op word} */
 
 /* Remove backslashes which are quoting backquotes from STRING.  Modifies
    STRING, and returns a pointer to it. */
@@ -279,6 +282,8 @@ extern char *cond_expand_word __P((WORD_DESC *, int));
 #define SD_NOQUOTEDELIM	0x04	/* don't let single or double quotes act as delimiters */
 #define SD_NOSKIPCMD	0x08	/* don't skip over $(, <(, or >( command/process substitution */
 #define SD_EXTGLOB	0x10	/* skip over extended globbing patterns if appropriate */
+#define SD_IGNOREQUOTE	0x20	/* single and double quotes are not special */
+#define SD_GLOB		0x40	/* skip over glob patterns like bracket expressions */
 
 extern int skip_to_delim __P((char *, int, char *, int));
 
